@@ -1,5 +1,5 @@
 # coding: UTF-8
-'''Mock D-BUS objects for test suites.'''
+'''Mock D-Bus objects for test suites.'''
 
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -8,10 +8,8 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__email__ = 'martin.pitt@ubuntu.com'
 __copyright__ = '(c) 2012 Canonical Ltd.'
-__license__ = 'LGPL 3+'
-__version__ = '0.18.1'
+__version__ = '0.21.0'
 
 from dbusmock.mockobject import (DBusMockObject, MOCK_IFACE,
                                  OBJECT_MANAGER_IFACE, get_object, get_objects)
