@@ -13,13 +13,13 @@ property such as 'NetworkingEnabled', or 'WirelessEnabled' etc. in
 # of the license.
 
 __author__ = 'Iftikhar Ahmad'
-__email__ = 'iftikhar.ahmad@canonical.com'
 __copyright__ = '(c) 2012 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
-import dbus
 import uuid
 import binascii
+from dataclasses import dataclass
+
+import dbus
 
 from dbusmock import MOCK_IFACE
 import dbusmock
@@ -40,6 +40,7 @@ SYSTEM_BUS = True
 IS_OBJECT_MANAGER = True
 
 
+@dataclass(frozen=True)
 class NMState:
     '''Global state
 
@@ -55,6 +56,7 @@ class NMState:
     NM_STATE_CONNECTED_GLOBAL = 70
 
 
+@dataclass(frozen=True)
 class NMConnectivityState:
     '''Connectvity state
 
@@ -67,6 +69,7 @@ class NMConnectivityState:
     NM_CONNECTIVITY_FULL = 4
 
 
+@dataclass(frozen=True)
 class NMActiveConnectionState:
     '''Active connection state
 
@@ -79,6 +82,7 @@ class NMActiveConnectionState:
     NM_ACTIVE_CONNECTION_STATE_DEACTIVATED = 4
 
 
+@dataclass(frozen=True)
 class InfrastructureMode:
     '''Infrastructure mode
 
@@ -97,6 +101,7 @@ class InfrastructureMode:
     }
 
 
+@dataclass(frozen=True)
 class DeviceState:
     '''Device states
 
@@ -117,6 +122,7 @@ class DeviceState:
     FAILED = 120
 
 
+@dataclass(frozen=True)
 class NM80211ApSecurityFlags:
     '''Security flags
 
@@ -142,6 +148,7 @@ class NM80211ApSecurityFlags:
     }
 
 
+@dataclass(frozen=True)
 class NM80211ApFlags:
     '''Device flags
 
@@ -189,15 +196,28 @@ def add_and_activate_connection(self, conn_conf, dev, ap):
     return (wifi_conn, active_conn)
 
 
-def get_device_by_ip_iface(self, iface):
+def get_device_by_ip_iface(_self, iface):
     NM = dbusmock.get_object(MANAGER_OBJ)
     for dev_path in NM.GetDevices():
         dev_obj = dbusmock.get_object(dev_path)
         interface = dev_obj.Get(DEVICE_IFACE, 'Interface')
         if interface == iface:
             return dev_path
+
+    return None
+
+
+def set_networking_enabled(self, networking_enabled):
+    if networking_enabled:
+        SetGlobalConnectionState(self, NMState.NM_STATE_CONNECTING)
+        SetGlobalConnectionState(self, NMState.NM_STATE_CONNECTED_LOCAL)
+        SetGlobalConnectionState(self, NMState.NM_STATE_CONNECTED_GLOBAL)
     else:
-        return None
+        SetGlobalConnectionState(self, NMState.NM_STATE_DISCONNECTING)
+        SetGlobalConnectionState(self, NMState.NM_STATE_DISCONNECTED)
+        SetGlobalConnectionState(self, NMState.NM_STATE_ASLEEP)
+
+    SetNetworkingEnabled(self, networking_enabled)
 
 
 def load(mock, parameters):
@@ -223,7 +243,8 @@ def load(mock, parameters):
                        ('DeactivateConnection', 'o', '', "self.deactivate_connection(self, args[0])"),
                        ('AddAndActivateConnection', 'a{sa{sv}}oo', 'oo', "ret = self.add_and_activate_connection("
                                                     "self, args[0], args[1], args[2])"),
-                       ('GetDeviceByIpIface', 's', 'o', 'ret = self.get_device_by_ip_iface(self, args[0])')]
+                       ('GetDeviceByIpIface', 's', 'o', 'ret = self.get_device_by_ip_iface(self, args[0])'),
+                       ('Enable', 'b', '', 'self.set_networking_enabled(self, args[0])')]
 
     mock.AddObject(MANAGER_OBJ,
                    MANAGER_IFACE,
@@ -236,6 +257,7 @@ def load(mock, parameters):
     obj.deactivate_connection = deactivate_connection
     obj.add_and_activate_connection = add_and_activate_connection
     obj.get_device_by_ip_iface = get_device_by_ip_iface
+    obj.set_networking_enabled = set_networking_enabled
 
     settings_props = {'Hostname': 'hostname',
                       'CanModify': True,
@@ -243,6 +265,7 @@ def load(mock, parameters):
     settings_methods = [('ListConnections', '', 'ao', "ret = self.Get('%s', 'Connections')" % SETTINGS_IFACE),
                         ('GetConnectionByUuid', 's', 'o', 'ret = self.SettingsGetConnectionByUuid(args[0])'),
                         ('AddConnection', 'a{sa{sv}}', 'o', 'ret = self.SettingsAddConnection(args[0])'),
+                        ('AddConnectionUnsaved', 'a{sa{sv}}', 'o', 'ret = self.SettingsAddConnection(args[0])'),
                         ('SaveHostname', 's', '', '')]
     mock.AddObject(SETTINGS_OBJ,
                    SETTINGS_IFACE,
@@ -253,7 +276,7 @@ def load(mock, parameters):
 
 @dbus.service.method(MOCK_IFACE,
                      in_signature='sssv', out_signature='')
-def SetProperty(self, path, iface, name, value):
+def SetProperty(_self, path, iface, name, value):
     obj = dbusmock.get_object(path)
     obj.Set(iface, name, value)
     obj.EmitSignal(iface, 'PropertiesChanged', 'a{sv}', [{name: value}])
@@ -272,9 +295,15 @@ def SetConnectivity(self, connectivity):
     self.SetProperty(MANAGER_OBJ, MANAGER_IFACE, 'Connectivity', dbus.UInt32(connectivity, variant_level=1))
 
 
+@dbus.service.method(MOCK_IFACE,
+                     in_signature='b', out_signature='')
+def SetNetworkingEnabled(self, networking_enabled):
+    self.SetProperty(MANAGER_OBJ, MANAGER_IFACE, 'NetworkingEnabled', dbus.Boolean(networking_enabled, variant_level=1))
+
+
 @dbus.service.method(MOCK_IFACE,
                      in_signature='ss', out_signature='')
-def SetDeviceActive(self, device_path, active_connection_path):
+def SetDeviceActive(_self, device_path, active_connection_path):
     dev_obj = dbusmock.get_object(device_path)
     dev_obj.Set(DEVICE_IFACE, 'ActiveConnection', dbus.ObjectPath(active_connection_path))
     old_state = dev_obj.Get(DEVICE_IFACE, 'State')
@@ -286,7 +315,7 @@ def SetDeviceActive(self, device_path, active_connection_path):
 
 @dbus.service.method(MOCK_IFACE,
                      in_signature='s', out_signature='')
-def SetDeviceDisconnected(self, device_path):
+def SetDeviceDisconnected(_self, device_path):
     dev_obj = dbusmock.get_object(device_path)
     dev_obj.Set(DEVICE_IFACE, 'ActiveConnection', dbus.ObjectPath('/'))
     old_state = dev_obj.Get(DEVICE_IFACE, 'State')
@@ -462,7 +491,7 @@ def AddAccessPoint(self, dev_path, ap_name, ssid, hw_address,
 
 @dbus.service.method(MOCK_IFACE,
                      in_signature='ssss', out_signature='s')
-def AddWiFiConnection(self, dev_path, connection_name, ssid_name, key_mgmt):
+def AddWiFiConnection(self, dev_path, connection_name, ssid_name, _key_mgmt):
     '''Add an available connection to an existing WiFi device and access point.
 
     You have to specify WiFi Device path, Connection object name,
@@ -556,7 +585,7 @@ def AddWiFiConnection(self, dev_path, connection_name, ssid_name, key_mgmt):
     main_connections.append(connection_path)
     settings_obj.Set(SETTINGS_IFACE, 'Connections', main_connections)
 
-    settings_obj.EmitSignal(SETTINGS_IFACE, 'NewConnection', 'o', [ap_path])
+    settings_obj.EmitSignal(SETTINGS_IFACE, 'NewConnection', 'o', [ap_path])  # pylint: disable=undefined-loop-variable
 
     return connection_path
 
