@@ -8,32 +8,27 @@
 # of the license.
 
 __author__ = 'Philip Withnall'
-__email__ = 'philip.withnall@collabora.co.uk'
 __copyright__ = '(c) 2013 Collabora Ltd.'
-__license__ = 'LGPL 3+'
 
-import unittest
-import sys
-import subprocess
-import time
+
 import os
+import shutil
+import subprocess
+import sys
+import time
+import unittest
 
 import dbus
 import dbus.mainloop.glib
 
-import dbusmock
-
 from gi.repository import GLib
 
+import dbusmock
+
 dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
 
-p = subprocess.Popen(['which', 'bluetoothctl'], stdout=subprocess.PIPE)
-p.communicate()
-have_bluetoothctl = (p.returncode == 0)
-
-p = subprocess.Popen(['which', 'pbap-client'], stdout=subprocess.PIPE)
-p.communicate()
-have_pbap_client = (p.returncode == 0)
+have_bluetoothctl = shutil.which('bluetoothctl')
+have_pbap_client = shutil.which('pbap-client')
 
 
 def _run_bluetoothctl(command):
@@ -88,10 +83,10 @@ class TestBlueZ5(dbusmock.DBusTestCase):
     '''Test mocking bluetoothd'''
 
     @classmethod
-    def setUpClass(klass):
-        klass.start_system_bus()
-        klass.dbus_con = klass.get_dbus(True)
-        (klass.p_mock, klass.obj_bluez) = klass.spawn_server_template(
+    def setUpClass(cls):
+        cls.start_system_bus()
+        cls.dbus_con = cls.get_dbus(True)
+        (cls.p_mock, cls.obj_bluez) = cls.spawn_server_template(
             'bluez5', {}, stdout=subprocess.PIPE)
 
     def setUp(self):
@@ -198,10 +193,10 @@ class TestBlueZObex(dbusmock.DBusTestCase):
     '''Test mocking obexd'''
 
     @classmethod
-    def setUpClass(klass):
-        klass.start_session_bus()
-        klass.start_system_bus()
-        klass.dbus_con = klass.get_dbus(True)
+    def setUpClass(cls):
+        cls.start_session_bus()
+        cls.start_system_bus()
+        cls.dbus_con = cls.get_dbus(True)
 
     def setUp(self):
         # bluetoothd
@@ -274,7 +269,7 @@ class TestBlueZObex(dbusmock.DBusTestCase):
         GLib.timeout_add(5000, ml.quit)
         ml.run()
 
-        out, err = process.communicate()
+        out = process.communicate()[0]
 
         lines = out.split('\n')
         lines = filter(lambda line: line != '', lines)
