@@ -7,20 +7,20 @@
 # of the license.
 
 __author__ = 'Iftikhar Ahmad'
-__email__ = 'iftikhar.ahmad@canonical.com'
 __copyright__ = '(c) 2012 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
-import unittest
-import sys
-import subprocess
-import dbus
-import dbus.mainloop.glib
-import dbusmock
 import os
 import re
+import shutil
+import subprocess
+import sys
+import unittest
 
 from gi.repository import GLib
+import dbus
+import dbus.mainloop.glib
+
+import dbusmock
 
 from dbusmock.templates.networkmanager import DeviceState
 from dbusmock.templates.networkmanager import NM80211ApSecurityFlags
@@ -33,9 +33,7 @@ from dbusmock.templates.networkmanager import (CSETTINGS_IFACE, MANAGER_IFACE,
 
 dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
 
-p = subprocess.Popen(['which', 'nmcli'], stdout=subprocess.PIPE)
-p.communicate()
-have_nmcli = (p.returncode == 0)
+have_nmcli = shutil.which('nmcli')
 
 
 @unittest.skipUnless(have_nmcli, 'nmcli not installed')
@@ -43,23 +41,23 @@ class TestNetworkManager(dbusmock.DBusTestCase):
     '''Test mocking NetworkManager'''
 
     @classmethod
-    def setUpClass(klass):
-        klass.start_system_bus()
-        klass.dbus_con = klass.get_dbus(True)
+    def setUpClass(cls):
+        cls.start_system_bus()
+        cls.dbus_con = cls.get_dbus(True)
 
         os.environ['G_DEBUG'] = 'fatal-warnings,fatal-criticals'
 
         # prepare environment which avoids translations
-        klass.lang_env = os.environ.copy()
+        cls.lang_env = os.environ.copy()
         try:
-            del klass.lang_env['LANG']
+            del cls.lang_env['LANG']
         except KeyError:
             pass
         try:
-            del klass.lang_env['LANGUAGE']
+            del cls.lang_env['LANGUAGE']
         except KeyError:
             pass
-        klass.lang_env['LC_MESSAGES'] = 'C'
+        cls.lang_env['LC_MESSAGES'] = 'C'
 
     def setUp(self):
         (self.p_mock, self.obj_networkmanager) = self.spawn_server_template(
@@ -451,7 +449,7 @@ class TestNetworkManager(dbusmock.DBusTestCase):
         caught = []
         ml = GLib.MainLoop()
 
-        def catch(*args, **kwargs):
+        def catch(*_, **kwargs):
             if (kwargs['interface'] == 'org.freedesktop.NetworkManager.Settings.Connection' and
                     kwargs['member'] == 'Updated'):
                 caught.append(kwargs['path'])
@@ -540,7 +538,7 @@ class TestNetworkManager(dbusmock.DBusTestCase):
         self.assertEqual(self.settings.GetConnectionByUuid(uuid), connectionPath)
 
         fakeuuid = '123123123213213'
-        with self.assertRaisesRegexp(dbus.exceptions.DBusException, ".*uuid.*%s$" % fakeuuid):
+        with self.assertRaisesRegex(dbus.exceptions.DBusException, ".*uuid.*%s$" % fakeuuid):
             self.settings.GetConnectionByUuid(fakeuuid)
 
 
