@@ -7,22 +7,19 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__email__ = 'martin.pitt@ubuntu.com'
 __copyright__ = '(c) 2013 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
-import unittest
-import sys
+import shutil
 import subprocess
+import sys
+import unittest
 
 import dbus
 
 import dbusmock
 
 
-p = subprocess.Popen(['which', 'pkcheck'], stdout=subprocess.PIPE)
-p.communicate()
-have_pkcheck = (p.returncode == 0)
+have_pkcheck = shutil.which('pkcheck')
 
 
 @unittest.skipUnless(have_pkcheck, 'pkcheck not installed')
@@ -30,9 +27,9 @@ class TestPolkit(dbusmock.DBusTestCase):
     '''Test mocking polkitd'''
 
     @classmethod
-    def setUpClass(klass):
-        klass.start_system_bus()
-        klass.dbus_con = klass.get_dbus(True)
+    def setUpClass(cls):
+        cls.start_system_bus()
+        cls.dbus_con = cls.get_dbus(True)
 
     def setUp(self):
         (self.p_mock, self.obj_polkitd) = self.spawn_server_template(
