@@ -7,23 +7,20 @@
 # of the license.
 
 __author__ = 'Iain Lane'
-__email__ = 'iain.lane@canonical.com'
 __copyright__ = '(c) 2013 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
-import unittest
 import os
-import sys
+import shutil
 import subprocess
+import sys
+import unittest
 
 import dbusmock
 
 # timedatectl keeps changing its CLI output
 TIMEDATECTL_NTP_LABEL = '(NTP enabled|synchronized|systemd-timesyncd.service active)'
 
-p = subprocess.Popen(['which', 'timedatectl'], stdout=subprocess.PIPE)
-p.communicate()
-have_timedatectl = (p.returncode == 0)
+have_timedatectl = shutil.which('timedatectl')
 
 
 @unittest.skipUnless(have_timedatectl, 'timedatectl not installed')
@@ -32,9 +29,9 @@ class TestTimedated(dbusmock.DBusTestCase):
     '''Test mocking timedated'''
 
     @classmethod
-    def setUpClass(klass):
-        klass.start_system_bus()
-        klass.dbus_con = klass.get_dbus(True)
+    def setUpClass(cls):
+        cls.start_system_bus()
+        cls.dbus_con = cls.get_dbus(True)
 
     def setUp(self):
         (self.p_mock, _) = self.spawn_server_template(
@@ -50,7 +47,7 @@ class TestTimedated(dbusmock.DBusTestCase):
             self.p_mock.terminate()
             self.p_mock.wait()
 
-    def run_timedatectl(self):
+    def run_timedatectl(self):  # pylint: disable=no-self-use
         return subprocess.check_output(['timedatectl'],
                                        universal_newlines=True)
 
